DependencySet class

Groups dependencies by their cacheability status.

Constructors

DependencySet({required List<PackageDependency> cacheable, required List<PackageDependency> uncacheable})
const
DependencySet.from(List<PackageDependency> dependencies)
Creates a DependencySet from a list of dependencies.
factory

Properties

all List<PackageDependency>
All dependencies combined.
no setter
cacheable List<PackageDependency>
Dependencies that can be cached (hosted + SDK).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uncacheable List<PackageDependency>
Dependencies that cannot be cached (path + git).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited