SummaryConfigException class
Raised when a package directory has no resolved
.dart_tool/package_config.json (i.e. pub get has not been run there),
or when a grouped bundle cannot be built (no SDK / no libraries).
- Implemented types
Constructors
- SummaryConfigException(String message)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited